@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------
-# Copyright (c) 2009-2010 Benito Jorge Bastida
+# Copyright (c) 2009-2011 Benito Jorge Bastida
 # All rights reserved.
 #  Redistribution and use in source and binary forms, with or without
 #  modification, are permitted provided that the following conditions are
@@ -45,19 +45,17 @@ from dajaxice.exceptions import FunctionNotCallableError, DajaxiceImportError
 
 log = logging.getLogger('dajaxice.DajaxiceRequest')
 
-# Python 2.7 has an importlib with import_module; for older Pythons,
-# Django's bundled copy provides it.
+# Python 2.7 has an importlib with import_module.
+# For older Pythons, Django's bundled copy provides it.
+# For older Django's dajaxice reduced_import_module.
 try:
     from importlib import import_module
-    DAJAXICE_MODERN_IMPORT = True
 except:
     try:
-        from django.utils import importlib
-        DAJAXICE_MODERN_IMPORT = True
+        from django.utils.importlib import import_module
     except:
-        DAJAXICE_MODERN_IMPORT = False
+        from dajaxice.utils import simple_import_module as import_module
 
-log.info('DAJAXICE_MODERN_IMPORT=%s' % DAJAXICE_MODERN_IMPORT)
 
 def safe_dict(d): 
     """
@@ -85,8 +83,7 @@ class DajaxiceRequest(object):
         
     @staticmethod
     def get_js_functions():
-        functions = dajaxice_functions.get_functions()
-        return functions
+        return dajaxice_functions.get_functions()
         
     @staticmethod
     def get_media_prefix():
@@ -120,7 +117,7 @@ class DajaxiceRequest(object):
     
     @staticmethod
     def get_exception_message():
-        return getattr(settings, 'DAJAXICE_EXCEPTION', u"'DAJAXICE_EXCEPTION'" )
+        return simplejson.dumps(getattr(settings, 'DAJAXICE_EXCEPTION', u"DAJAXICE_EXCEPTION" ))
         
     def _is_callable(self):
         """
@@ -133,34 +130,7 @@ class DajaxiceRequest(object):
         Return a callable ajax function.
         This function should be imported according the Django version.
         """
-        if DAJAXICE_MODERN_IMPORT:
-            return self._modern_get_ajax_function()
-        else:
-            return self._old_get_ajax_function()
-    
-    def _old_get_ajax_function(self):
-        """
-        Return a callable ajax function.
-        This function doesn't uses django.utils.importlib
-        """
-        
-        self.module_import_name = "%s.%s" % ( self.project_name, self.module)   
-        try:
-            return self._old_import()
-        except:
-            self.module_import_name = self.module
-            return self._old_import()
-    
-    def _old_import(self):
-        """
-        Import this.module_import_name 
-        This function doesn't uses django.utils.importlib
-        """
-        try:
-            mod = __import__(self.module_import_name , None, None, [self.method])
-            return mod.__getattribute__(self.method)
-        except:
-            raise DajaxiceImportError()
+        return self._modern_get_ajax_function()
         
     def _modern_get_ajax_function(self):
         """
@@ -175,9 +145,8 @@ class DajaxiceRequest(object):
             return self._modern_import()
     
     def _modern_import(self):
-        from django.utils import importlib
         try:
-            mod = importlib.import_module(self.module_import_name)
+            mod = import_module(self.module_import_name)
             return mod.__getattribute__(self.method)
         except:
             raise DajaxiceImportError()
@@ -188,7 +157,7 @@ class DajaxiceRequest(object):
         """
         if self._is_callable():
             log.debug('Function %s is callable' % self.full_name)
-            callback = self.request.POST.get('callback')
+            callback = self.request.POST.get('callback', None)
             
             argv = self.request.POST.get('argv')
             if argv != 'undefined':
@@ -206,14 +175,21 @@ class DajaxiceRequest(object):
             
             try:
                 thefunction = self._get_ajax_function()
-                response = '%s(%s)' % ( callback, thefunction(self.request, **argv) )
+                if callback:
+                    response = '%s(%s)' % ( callback, thefunction(self.request, **argv) )
+                else:
+                    response = '%s' % thefunction(self.request, **argv)
+                    
             except Exception, e:
                 trace = '\n'.join(traceback.format_exception(*sys.exc_info()))
                 log.error(trace)
                 if DajaxiceRequest.get_debug():
                     response = 'alert("%s")' % trace.replace('"','\\"').replace('\n','\\n')
                 else:
-                    response = '%s(%s)' % ( callback, DajaxiceRequest.get_exception_message())
+                    if callback:
+                        response = '%s(%s)' % ( callback, DajaxiceRequest.get_exception_message())
+                    else:
+                        response = '%s' % DajaxiceRequest.get_exception_message()
                     
                 if DajaxiceRequest.get_notify_exceptions():
                     self.notify_exception(self.request, sys.exc_info())
