@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------
-# Copyright (c) 2009-2010 Benito Jorge Bastida
+# Copyright (c) 2009-2011 Benito Jorge Bastida
 # All rights reserved.
 #  Redistribution and use in source and binary forms, with or without
 #  modification, are permitted provided that the following conditions are
@@ -32,10 +32,13 @@
 #----------------------------------------------------------------------
 
 from django.core.management.base import BaseCommand
-from dajaxice.core import DajaxiceRequest
 from django.template.loader import render_to_string
 from optparse import make_option
 
+from dajaxice.core import DajaxiceRequest
+from dajaxice.core import dajaxice_autodiscover
+dajaxice_autodiscover()
+
 class Command(BaseCommand):
     help = "Generate dajaxice.core.js file to import it as static file"
     args = "[--compile]"
@@ -51,7 +54,7 @@ class Command(BaseCommand):
             'DAJAXICE_URL_PREFIX': DajaxiceRequest.get_media_prefix(),
             'DAJAXICE_XMLHTTPREQUEST_JS_IMPORT':DajaxiceRequest.get_xmlhttprequest_js_import(),
             'DAJAXICE_JSON2_JS_IMPORT':DajaxiceRequest.get_json2_js_import(),
-            'DAJAXICE_EXCEPTION':DajaxiceRequest.get_exception_message(),
+            'DAJAXICE_EXCEPTION':DajaxiceRequest.get_exception_message()
              }
         js = render_to_string('dajaxice/dajaxice.core.js', data )
         if compile_output.lower() == "closure":
