@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------
-# Copyright (c) 2009-2010 Benito Jorge Bastida
+# Copyright (c) 2009-2011 Benito Jorge Bastida
 # All rights reserved.
 #  Redistribution and use in source and binary forms, with or without
 #  modification, are permitted provided that the following conditions are
@@ -30,10 +30,19 @@
 #  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 #  DAMAGE.
 #----------------------------------------------------------------------
+
 def deserialize_form(data):
     """
     Create a new QueryDict from a serialized form.
     """
     from django.http import QueryDict
     data = QueryDict(query_string=unicode(data).encode('utf-8'))
-    return data
\ No newline at end of file
+    return data
+
+def simple_import_module(name):
+    """
+    Reduced version of import_module
+    """
+    import sys
+    __import__(name)
+    return sys.modules[name]
\ No newline at end of file
